##  Adding and Editing Data in a Fact Sheet
You can add and edit data in fact sheets by following these steps:
  1. Hover over the section you want to update and click the + Add or Edit button that appears in the upper right corner of the section.
  2. Add or modify the information as needed.
  3. Click Save to complete. If you're working through a new fact sheet, use the Save & Next button to automatically move to the next section.


![Adding and Editing Data in a Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27532ab37a441014bf2f8a9050e8e809_LowRes.gif)
Adding and Editing Data in a Fact Sheet
Text fields in fact sheets support rich text editing, including bold, italic, underline, strikethrough, bulleted and numbered lists, as well as hyperlinks.
**Tip**
  * Navigate between fact sheet sections using the list in the upper-left corner of the Fact Sheet tab.
  * Find specific sections, subsections, or fields using the search field in the upper-right corner.
  * To direct users to specific information on a fact sheet, copy the link to a section or subsection and then share it.
